    SUBROUTINE CONDLOAD(QLIQ,QICE,WTW,DZ,BOTERM,ENTERM,RATE,QNEWLQ,QNEWIC,QLQOUT,QICOUT)
!
    USE F77KINDS
!
    IMPLICIT NONE
!           
    REAL(KIND=R4KIND), PARAMETER :: G  = 9.8
!
    REAL(KIND=R4KIND), INTENT (IN)                                                              ::&
    & DZ , BOTERM , ENTERM , RATE
!
    REAL(KIND=R4KIND), INTENT (INOUT)                                                           ::&
    & QLIQ   , QICE  , WTW   , QNEWLQ , QNEWIC ,                                                  &
    & QLQOUT , QICOUT 
!
    REAL(KIND=R4KIND)                                                                           ::&
    & WAVG  , QTOT  , QNEW  , QEST  , G1    ,                                                     &
    & CONV  , RATIO3, OLDQ  , RATIO4, DQ    ,                                                     &
    & PPTDRG
!----------------------------------------------------------------------
!*** THIS PRECIPITATION FALLOUT SCHEME IS BASED ON THE SCHEME USED
!*** BY OGURA AND CHO (1973). LIQUID WATER FALLOUT FROM A PARCEL IS
!*** CALCULATED USING THE EQUATION DQ=-RATE*Q*DT, BUT TO SIMULATE A
!*** QUASI-CONTINUOUS PROCESS, AND TO ELIMINATE A DEPENDENCY ON
!*** VERTICAL RESOLUTION THIS IS EXPRESSED AS Q=Q*EXP(-RATE*DZ).
!----------------------------------------------------------------------
!
    QTOT = QLIQ + QICE
    QNEW = QNEWLQ + QNEWIC

!*** ESTIMATE THE VERTICAL VELOCITY SO THAT AN AVERAGE VERTICAL VELOCITY
!*** CAN BE CALCULATED TO ESTIMATE THE TIME REQUIRED FOR ASCENT BETWEEN
!*** MODEL LEVELS.

    QEST = 0.5 * (QTOT + QNEW)
      G1 = WTW + BOTERM - ENTERM - 2. * G * DZ * QEST / 1.5
    IF(G1 < 0.0)G1 = 0.
    WAVG = (SQRT(WTW) + SQRT(G1)) / 2.
    IF(WAVG < 1.E-8) THEN
        CONV = 50.0
    ELSE
        CONV = RATE * DZ / WAVG
    ENDIF
!
    CONV = AMIN1(CONV,50.)
    CONV = AMAX1(CONV,0.)
!
!*** RATIO3 IS THE FRACTION OF LIQUID WATER IN FRESH CONDENSATE,
!*** RATIO4 IS THE FRACTION OF LIQUID WATER IN THE TOTAL AMOUNT OF
!*** CONDENSATE INVOLVED IN THE PRECIPITATION PROCESS.
!*** NOTE THAT ONLY 60% OF THE FRESH CONDENSATE IS ALLOWED
!*** TO PARTICIPATE IN THE CONVERSION PROCESS.

    RATIO3 = QNEWLQ / (QNEW + 1.E-10)
! OLDQ = QTOT
      QTOT = QTOT + 0.6 * QNEW
      OLDQ = QTOT
    RATIO4 = (0.6 * QNEWLQ + QLIQ) / (QTOT + 1.E-10)
      QTOT = QTOT * EXP(-CONV)

!*** DETERMINE THE AMOUNT OF PRECIPITATION THAT FALLS OUT OF THE
!*** UPDRAFT PARCEL AT THIS LEVEL.

        DQ = OLDQ - QTOT
    QLQOUT = RATIO4 * DQ
    QICOUT = (1. - RATIO4) * DQ

!*** ESTIMATE THE MEAN LOAD OF CONDENSATE ON THE UPDRAFT IN THE LAYER,
!*** CALCULATE VERTICAL VELOCITY.

    PPTDRG = 0.5 * (OLDQ + QTOT - 0.2 * QNEW)
       WTW = WTW + BOTERM - ENTERM - 2.* G * DZ * PPTDRG / 1.5

!*** DETERMINE THE NEW LIQUID WATER AND ICE CONCENTRATIONS INCLUDING
!*** LOSSES DUE TO PRECIPITATION AND GAINS FROM CONDENSATION.

      QLIQ = RATIO4 * QTOT + RATIO3 * 0.4 * QNEW
      QICE = (1.- RATIO4) * QTOT + (1.- RATIO3) * 0.4 * QNEW
    QNEWLQ = 0.
    QNEWIC = 0.
!----------------------------------------------------------------------
    RETURN
    END SUBROUTINE CONDLOAD
