    SUBROUTINE DTFRZNEW(TU,P,THTEU,QU,QFRZ,QICE,ALIQ,BLIQ,CLIQ,DLIQ)
!----------------------------------------------------------------------
!
    USE F77KINDS
!
    IMPLICIT NONE   
!
    REAL   (KIND=R4KIND), INTENT (IN)                                                           ::&
    & P , QFRZ , ALIQ , BLIQ , CLIQ , DLIQ
!
    REAL   (KIND=R4KIND), INTENT (INOUT)                                                        ::&
    & TU  , QU  , QICE , THTEU
!
    REAL   (KIND=R4KIND)                                                                        ::&
    & RLC  , RLS , RLF , CP    , A  ,                                                             &
    & DTFRZ, ES  , QS  , DQEVAP, PI 
    
!
!***  ALLOW THE FREEZING OF LIQUID WATER IN THE UPDRAFT TO PROCEED AS
!***  AN APPROXIMATELY LINEAR FUNCTION OF TEMPERATURE IN THE TEMPERATURE
!***  RANGE TTFRZ TO TBFRZ.
!***  FOR COLDER TERMPERATURES, FREEZE ALL LIQUID WATER.
!***  THERMODYNAMIC PROPERTIES ARE STILL CALCULATED WITH RESPECT TO
!***  LIQUID WATER TO ALLOW THE USE OF LOOKUP TABLE TO EXTRACT TMP
!***  FROM THETAE.

!----------------------------------------------------------------------
    RLC = 2.5E6 - 2369.276 * (TU - 273.16)
    RLS = 2833922. -259.532 * (TU - 273.16)
    RLF = RLS - RLC
    CP = 1005.7 * (1. + 0.89 * QU)

!***  A = D(es)/DT IS THAT CALCULATED FROM BUCKS (1981) EMPIRICAL
!***  FORMULAS FOR SATURATION VAPOR PRESSURE.

        A = (CLIQ - BLIQ * DLIQ) / ((TU - DLIQ) * (TU - DLIQ))
    DTFRZ = RLF * QFRZ / (CP + RLS * QU * A)
       TU = TU + DTFRZ
          
       ES = ALIQ*EXP((BLIQ*TU-CLIQ)/(TU-DLIQ))
       QS = ES * 0.622 / (P - ES)

!***  FREEZING WARMS THE AIR AND IT BECOMES UNSATURATED.  ASSUME THAT
!***  SOME OF THE LIQUID WATER THAT IS AVAILABLE FOR FREEZING EVAPORATES
!***  TO MAINTAIN SATURATION.  SINCE THIS WATER HAS ALREADY BEEN
!***  TRANSFERRED TO THE ICE CATEGORY, SUBTRACT IT FROM ICE CONCENTRATION,
!***  THEN SET UPDRAFT MIXING RATIO AT THE NEW TEMPERATURE TO THE
!***  SATURATION VALUE.

    DQEVAP = QS - QU
      QICE = QICE - DQEVAP
        QU = QU + DQEVAP
        PI = (1.E5 / P) ** (0.2854 * (1. - 0.28 * QU))
     THTEU = TU * PI * EXP((3374.6525 / TU - 2.5403) * QU * (1. + 0.81 * QU))
!----------------------------------------------------------------------
    RETURN
    END SUBROUTINE DTFRZNEW
