    SUBROUTINE KFDRIVE(HTOP,HBOT,CNVTOP,CNVBOT)
!     ******************************************************************
!$$$  SUBPROGRAM DOCUMENTATION BLOCK
!                .      .    .
! SUBPROGRAM:    KFDRIVE     CONVECTIVE PRECIPITATION PARAMETERIZATION
!   PRGRMMR: KAIN            ORG: W/NP2      DATE: 00-03-30

! ABSTRACT:
!     KFDRIVE IS THE MAIN DRIVER FOR THE KAIN-FRITSCH CONVECTION.
!     GRID POINTS ARE ISOLATED TO BE CHECKED FOR POSSIBLE
!     INITAITION OF THE K-F SCHEME.


! PROGRAM HISTORY LOG:
!   ??-??-??  KAIN       - ORIGINATOR
!   00-04-13  BLACK      - INCORPORATED INTO ETA MODEL
!   22-09-14  GUSTAVO    - MODERNIZATION OF THE CODE, INCLUDING:
!                        * REPLACEMENT OF COMMONS BLOCK FOR MODULES

! USAGE: CALL KFDRIVE FROM MAIN PROGRAM EBU

!   INPUT ARGUMENT LIST:
!     NONE

!   OUTPUT ARGUMENT LIST:
!     HTOP   - CONVECTIVE CLOUD TOP (MODEL LAYER) FOR RADTN
!     HBOT   - CONVECTIVE CLOUD BOTTOM (MODEL LAYER) FOR RADTN
!     CNVTOP - CONVECTIVE CLOUD TOP (MODEL LAYER) FOR CHKOUT
!     CNVBOT - CONVECTIVE CLOUD BOTTOM (MODEL LAYER) FOR CHKOUT

!   SUBPROGRAMS CALLED:

!     UNIQUE:
!        KFPARA

!     LIBRARY:
!        NONE

!   COMMON BLOCKS: CTLBLK
!                  VRBLS
!                  PVRBLS
!                  MASKS
!                  CONTIN
!                  DYNAM
!                  LOOPS
!                  KFFDBK

! ATTRIBUTES:
!   LANGUAGE: FORTRAN 90
!   MACHINE : IBM SP
!$$$
!----------------------------------------------------------------------
    USE CONTIN
    USE CTLBLK 
    USE DYNAM 
    USE EXCHM
    USE LOOPS
    USE MASKS
    USE MPPCOM
    USE KFFDBK
    USE PARMETA
    USE PVRBLS
    USE VRBLS
!
    IMPLICIT NONE
!
    INCLUDE "EXCHM.h"
    INCLUDE "mpif.h"
!
    REAL(KIND=R4KIND), PARAMETER :: CP   = 1004.6
    REAL(KIND=R4KIND), PARAMETER :: XLV  = 2.5E6
    REAL(KIND=R4KIND), PARAMETER ::  G   = 9.8
!GSM    REAL(KIND=R4KIND), PARAMETER ::  R   = 287.04
    REAL(KIND=R4KIND), PARAMETER :: ALIQ = 613.3
    REAL(KIND=R4KIND), PARAMETER :: BLIQ = 17.502
    REAL(KIND=R4KIND), PARAMETER :: CLIQ = 4780.8
    REAL(KIND=R4KIND), PARAMETER :: DLIQ = 32.19    
    REAL(KIND=R4KIND), PARAMETER :: ROVG = 287.04 / G
!
    REAL   (KIND=R4KIND), DIMENSION(IDIM1:IDIM2, JDIM1:JDIM2), INTENT(IN)                       ::&
    & HTOP   , HBOT , CNVTOP , CNVBOT
!    
    REAL   (KIND=R4KIND), DIMENSION(LM)                                                         ::&
    & SEM , SEMS , PRS , TV0 , Z00 , SED , DP
!    
    REAL   (KIND=R4KIND)                                                                        ::&
    & W0    , PSFCK , P200 , P400 , TTMP ,                                                        &
    & QTMP  , ES    , QSS  
!
    INTEGER(KIND=I4KIND), DIMENSION(IDIM1:IDIM2)                                                ::&
    & ICUYES, LSB
!
    INTEGER(KIND=I4KIND), DIMENSION(JDIM1:JDIM2)                                                ::&
    & NSHALL      
!
    INTEGER(KIND=I4KIND)                                                                        ::&
    & NCUYES   , LG  , I    , J , K    ,                                                          &
    & L200     , L400, ISINK, NL, NSHAL,                                                          &
    & NSHALLOW , IRECV
!    
!------------------------------------------------------------------
!...NOTE:  SEARCHING ONLY LOWEST 200 mb!!!!!
!------------------------------------------------------------------
    DO K=1,LM
        DO J=MYJS,MYJE
            DO I=MYIS,MYIE
                          W0 = -OMGALF(I,J,K) * CP / (G * DT)
                W0AVG(I,J,K) = (W0AVG(I,J,K) * (TST - 1.) + W0) / TST
            END DO
        END DO
    END DO

! LG      IF(MOD(NTSD-NCLDCK/2,NCLDCK).NE.0)RETURN
    IF(MOD(NTSD,NCLDCK) /= 0)RETURN
    IF (MYPE == 0) WRITE(*,*)"CALL KF"

    DO J=JDIM1,JDIM2
        NSHALL(J) = 0
    END DO
!- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

!***  MAKE A QUICK FOR CHECK FOR THESE THINGS THAT CAN ELIMINATE
!***  GRID POINTS FROM THE POSSIBILITY OF CONVECTIVE INITIATION:

!        1.) CONVECTION ALREADY ACTIVE AT THIS POINT
!        2.) POINT CLOSE TO GRID-DOMAIN BOUNDARY
!        3.) DOWNWARD MOTION AT ALL LEVELS IN LOWEST 300 MB
!        4.) NO CAPE
!- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

!$omp parallel do
!$omp& private(DP,ES,I,ICUYES,ISINK,L,L200,L400,LG,LSB,
!$omp&         NCUYES,P200,P400,PRS,PSFCK,QSS,QTMP,
!$omp&         SED,SEM,SEMS,TTMP,TV0,Z00)
    DO 100 J=MYJS2,MYJE2
    
        NCUYES = 0
    
        DO I=MYIS,MYIE
            ICUYES(I) = 0
               LSB(I) = 0
        ENDDO
    
        DO 60 I=MYIS1,MYIE1
        
            IF(NCA(I,J) > NCLDCK .OR. HBM2(I,J) == 0.)GO TO 60
               LG = LMH(I,J)
            PSFCK = PD(I,J) * RES(I,J) * AETA(LG) + PT
        !     P300 = PSFCK - 3.E4
             P200 = PSFCK - 2.E4
             P400 = PSFCK - 4.E4
        
            DO K=LG,1,-1
                PRS(K) = PD(I,J) * RES(I,J) * AETA(K) + PT
            ENDDO
        
            DO K=LG,1,-1
                IF(PRS(K) > P200)L200 = K
                IF(PRS(K) > P400)L400 = K
            ENDDO
        
!***  VERTICAL VELOCITY MUST BE UPWARD AT SOME LEVEL IN THE
!***  LOWEST 300 MB...
!***  LOWEST 400 MB...!!!!! 9/25/97 JSK
        
            ISINK = 0
        
        !     DO K=LG,L400,-1
            DO K=LG,L200,-1
            !       IF(OMGALF(I,J,K).LT.0.)GO TO 25
                IF(OMGALF(I,J,K) < 0. .OR. Q2(I,J,K) > 1.)GO TO 25
            ENDDO
        
            ISINK = 1
        
            25 CONTINUE
        
!***  CALCULATE MOIST STATIC ENERGY AND SATURATION MOIST STATIC ENERGY AT EACH VERTICAL LEVEL.
!        
            DO K=LG,1,-1
                 TTMP  = T(I,J,K)
                 QTMP  = Q(I,J,K)
                 DP(K) = (ETA(K+1) - ETA(K)) * PD(I,J) * RES(I,J)
                TV0(K) = TTMP * (1. + 0.608 * QTMP)
            
                IF(K == LG)THEN
                    Z00(K) = 0.
                ELSE
                    Z00(K) = Z00(K+1) - ROVG * 0.5 * (TV0(K) + TV0(K+1)) * ALOG(PRS(K) / PRS(K+1))
                ENDIF
            
                    ES  = ALIQ * EXP((BLIQ * TTMP - CLIQ) / (TTMP - DLIQ))
                   QSS  = 0.622 * ES / (PRS(K) - ES)
                 SED(K) = CP * TTMP + G * Z00(K)
                SEMS(K) = SED(K) + XLV * QSS
                 SEM(K) = SED(K) + XLV * QTMP
            END DO
        
!***  IF AIR IS SINKING EVERYWHERE IN LOWEST 400 MB,
!***  REQUIRE SUPERADIABATIC LAYER IN LOWEST 200 MB
!***  BEFORE CHECKING FOR CONVECTION IN KF SCHEME.
        
            IF(ISINK == 1)THEN
                DO K=LG,L200-1,-1
                    DO NL=K-1,L200,-1
                        IF(SED(K) > SED(NL))THEN
                                    NCUYES = NCUYES + 1
                            ICUYES(NCUYES) = I
                                    LSB(I) = LG - K + 1
                            GO TO 60
                        END IF
                    END DO
                END DO
            ELSE
            
!***  IF THERE IS UPWARD MOTION, REQUIRE CONDITIONAL INSTABILITY
!***  FOR A PARCEL ORIGINATING IN THE LOWEST 400 MB.

!	DO K=LG,L400,-1
                DO K=LG,L200,-1
                    DO NL=K-1,1,-1
                        IF(SEM(K) > SEMS(NL))THEN
                                    NCUYES = NCUYES + 1
                            ICUYES(NCUYES) = I
                                    LSB(I) = LG - K + 1
                            GO TO 60
                        END IF
                    END DO
                END DO
            
            END IF
!-----------------------------------------------------------------
            CONTINUE       ! END OF I LOOP
        60 END DO
!-----------------------------------------------------------------
        IF(NCUYES > 0)THEN
            CALL KFPARA(NCUYES,ICUYES,J,LSB,HTOP,HBOT,CNVTOP,CNVBOT,NSHALL(J))
        ENDIF
!-----------------------------------------------------------------
        CONTINUE       ! End of J loop
    100 END DO
!-----------------------------------------------------------------
    NSHALLOW = 0

    DO J=MYJS2,MYJE2
        NSHALLOW = NSHALLOW + NSHALL(J)
    END DO

    CALL MPI_REDUCE(NSHALLOW,NSHAL,1,MPI_INTEGER,MPI_SUM,0,MPI_COMM_COMP,IRECV)
!-----------------------------------------------------------------
!     IF(MYPE.EQ.0)THEN
!       PRINT*,'at NTSD =',NTSD,' NSHALL =',NSHAL
!     END IF
!-----------------------------------------------------------------
    RETURN
    END SUBROUTINE KFDRIVE
