    SUBROUTINE KFTEND
!     ******************************************************************
!$$$  SUBPROGRAM DOCUMENTATION BLOCK
!                .      .    .
! SUBPROGRAM:    KFDRIVE     CONVECTIVE PRECIPITATION PARAMETERIZATION
!   PRGRMMR: KAIN            ORG: W/NP2      DATE: 00-03-30

! ABSTRACT:
!     KFTEND FEEDS TENDENCIES GENERATED BY THE KAIN-FRITSCH CONVECTIVE
!     SCHEME INTO THE GRIDSCALE TEMPERATURE AND MOISTURE FIELDS


! PROGRAM HISTORY LOG:
!   ??-??-??  KAIN       - ORIGINATOR
!   00-04-17  BLACK      - INCORPORATED INTO ETA MODEL
!   22-09-14  GUSTAVO    - MODERNIZATION OF THE CODE, INCLUDING:
!                        * REPLACEMENT OF COMMONS BLOCK FOR MODULES


! USAGE: CALL KFTEND FROM MAIN PROGRAM EBU

!   INPUT ARGUMENT LIST:
!     NONE

!   OUTPUT ARGUMENT LIST:
!     NONE

!   SUBPROGRAMS CALLED:

!     UNIQUE:
!        KFPARA

!     LIBRARY:
!        NONE

!   COMMON BLOCKS: CTLBLK
!                  VRBLS
!                  DYNAM
!                  PVRBLS
!                  ACMCLH
!                  ACMPRE
!                  CNVCLD
!                  MASKS
!                  LOOPS
!                  KFFDBK
!                  CLDWTR

! ATTRIBUTES:
!   LANGUAGE: FORTRAN 90
!   MACHINE : IBM SP
!$$$
!----------------------------------------------------------------------
!----------------------------------------------------------------------
    USE ACMCLH
    USE ACMPRE
    USE CLDWTR
    USE CNVCLD
    USE CTLBLK
    USE DYNAM
    USE F77KINDS
    USE KFFDBK
    USE LOOPS
    USE MASKS
    USE MPPCOM
    USE PARMETA
    USE PVRBLS
    USE VRBLS
!
    IMPLICIT NONE
!
!
    INTEGER (KIND=I4KIND)                                                                       ::&
    & I , J , K , LG
!
!----------------------------------------------------------------------
!**********************************************************************
!----------------------------------------------------------------------

!***  FEEDBACK CONVECTIVE TENDENCIES EACH TIME STEP

! omp parallel do
! omp& private(i,l,lg)
    DO 30 J=MYJS2,MYJE2
        DO 30 I=MYIS1,MYIE1
        
            IF(NCA(I,J) <= 0)GO TO 30
            LG = LMH(I,J)
        
            DO K=1,LG
                    T(I,J,K) = T(I,J,K) + DTDT(I,J,K) * DT * HBM2(I,J)
                    Q(I,J,K) = Q(I,J,K) + DQDT(I,J,K) * DT * HBM2(I,J)
                  CWM(I,J,K) = CWM(I,J,K) + DQCDT(I,J,K) * DT * HBM2(I,J)
                TCUCN(I,J,K) = DTDT(I,J,K) * DT * HBM2(I,J) + TCUCN(I,J,K)
            END DO
        
            CUPREC(I,J) = CUPREC(I,J) + RAINCV(I,J) * 0.01
            ACPREC(I,J) = ACPREC(I,J) + RAINCV(I,J) * 0.01
             CUPPT(I,J) = CUPPT(I,J) + RAINCV(I,J) * 0.01
              PREC(I,J) = PREC(I,J) + RAINCV(I,J) * 0.01
        
             PPTKF(I,J) = PPTKF(I,J) + RAINCV(I,J) * 0.01
        
            IF(NCAD(I,J) > 0)THEN
                 TNCA(I,J) = TNCA(I,J) + 1.
                SPCLB(I,J) = SPCLB(I,J) + PCLB(I,J)
            
!***  USE PEAK VALUE OF UMF INSTEAD OF 1 HOUR AVG.
!***  DO THE SAME FOR PSRC.
            
                SPSRC(I,J) = AMAX1(PSRC(I,J),SPSRC(I,J))
                SUMFB(I,J) = AMAX1(UMFB(I,J),SUMFB(I,J))
                 NCAD(I,J) = NCAD(I,J) - 1
            END IF
!----------------------------------------------------------------------

!***  UPDATE THE CONVECTIVE TIME SCALE ARRAY.
        
            NCA(I,J)=NCA(I,J)-1
        
            IF(NCA(I,J) == 0)THEN
                RAINCV(I,J)=0.
            
                DO K=1,LM
                    DTDT(I,J,K)=0.
                    DQDT(I,J,K)=0.
                    DQCDT(I,J,K)=0.
                END DO
            
                PSRC(I,J) = 0.
                PCLB(I,J) = 0.
                UMFB(I,J) = 0.
            END IF
!----------------------------------------------------------------------
    30 END DO
!----------------------------------------------------------------------
    RETURN
    END SUBROUTINE KFTEND
