    SUBROUTINE LUTAB
!----------------------------------------------------------------------
!** THIS SUBROUTINE IS A LOOKUP TABLE.
!** GIVEN A SERIES OF SERIES OF SATURATION EQUIVALENT POTENTIAL
!** TEMPERATURES, THE TEMPERATURE IS CALCULATED.
!----------------------------------------------------------------------
    USE F77KINDS
    USE KFLUT  
!
    IMPLICIT NONE
!
    REAL   (KIND=R4KIND)                                                                               ::&
    & ASTRT , DPR   , TEMP  , AINC, A1   ,                                                               &
    & P     , ES    , QS    , PI  , THES ,                                                               &
    & TGUES , THGUES, F0    , T1  , T0   ,                                                               &
    & THTGS , F1    , DT    , DTH , TMIN ,                                                               &
    & TOLER    
!
    INTEGER (KIND=I4KIND)                                                                              ::&
    & KP , IT , ITCNT , I                                                                  
!
!----------------------------------------------------------------------
!*** EQUIVALENT POTENTIAL TEMPERATURE INCREMENT
!
!    REAL(KIND=R4KIND), PARAMETER :: DTH  = 1.
   DATA DTH/1./
!----------------------------------------------------------------------
!*** MINIMUM STARTING TEMP
!
!    REAL(KIND=R4KIND), PARAMETER :: TMIN  = 150.
    DATA TMIN/150./
!----------------------------------------------------------------------
!*** TOLERANCE FOR ACCURACY OF TEMPERATURE
!
!    REAL(KIND=R4KIND), PARAMETER :: TOLER  = 0.001
    DATA TOLER/0.001/
!----------------------------------------------------------------------
!*** BOTTOM PRESSURE (PASCALS)
!
    REAL(KIND=R4KIND), PARAMETER :: PBOT  = 110000.0
!
!----------------------------------------------------------------------
!
!*** DEFINE CONSTANTS FOR CALCULATION OF SATURATION VAPOR PRESSURE
!*** ACCORDING TO BUCK (J. APPL. METEO., DECEMBER, 1981)
!
    REAL(KIND=R4KIND), PARAMETER :: ALIQ = 613.3
    REAL(KIND=R4KIND), PARAMETER :: BLIQ = 17.502
    REAL(KIND=R4KIND), PARAMETER :: CLIQ = 4780.8
    REAL(KIND=R4KIND), PARAMETER :: DLIQ = 32.19
!
!----------------------------------------------------------------------
!*** COMPUTE PARAMETERS
!----------------------------------------------------------------------
!*** 1./(SAT. EQUIV. THETA INCREMENT)
!
    RDTHK = 1. / DTH
!
!----------------------------------------------------------------------
!*** PRESSURE INCREMENT
!
    DPR = (PBOT - PTOP) / FLOAT(KFNP-1)
!
!----------------------------------------------------------------------
!*** 1./(PRESSURE INCREMENT)
!
    RDPR = 1. / DPR
!
!----------------------------------------------------------------------
!*** CALCULATE THE STARTING SAT. EQUIV. THETA

    TEMP = TMIN
       P = PTOP - DPR

    DO KP=1,KFNP
                P = P + DPR
               ES = ALIQ * EXP((BLIQ * TEMP - CLIQ) / (TEMP - DLIQ))
               QS = 0.622 * ES / (P - ES)
               PI = (1.E5 / P) ** (0.2854 * (1. -0.28 * QS))
        THE0K(KP) = TEMP * PI * EXP((3374.6525 / TEMP - 2.5403) * QS * (1. + 0.81 * QS))
    END DO
!----------------------------------------------------------------------
!
!*** COMPUTE TEMPERATURES FOR EACH SAT. EQUIV. POTENTIAL TEMP.

    P = PTOP - DPR

    DO 60 KP=1,KFNP
        THES = THE0K(KP) - DTH
           P = P + DPR
    
        DO 50 IT=1,KFNT
        
!*** DEFINE SAT. EQUIV. POT. TEMP.
        
            THES = THES + DTH
        
!*** ITERATE TO FIND TEMPERATURE
!*** FIND INITIAL GUESS
        
            IF(IT == 1)THEN
                TGUES = TMIN
            ELSE
                TGUES = TTAB(IT-1,KP)
            END IF
        
                ES = ALIQ * EXP((BLIQ * TGUES - CLIQ) / (TGUES - DLIQ))
                QS = 0.622 * ES / (P - ES)
                PI = (1.E5/P) ** (0.2854 * (1. - 0.28 * QS))
            THGUES = TGUES * PI * EXP((3374.6525 / TGUES - 2.5403) * QS * (1. + 0.81 * QS))
                F0 = THGUES - THES
                T1 = TGUES - 0.5 * F0
                T0 = TGUES
             ITCNT = 0
        
!*** ITERATION LOOP
        
            30 CONTINUE
        
               ES = ALIQ * EXP((BLIQ * T1 - CLIQ) / (T1 - DLIQ))
               QS = 0.622 * ES / (P - ES)
               PI = (1.E5 / P) ** (0.2854 *(1. - 0.28 * QS))
            THTGS = T1 * PI * EXP((3374.6525 / T1 - 2.5403) * QS * (1. + 0.81 * QS))
               F1 = THTGS - THES
            IF(ABS(F1) < TOLER)GO TO 40
            ITCNT = ITCNT + 1
        
            IF(ITCNT > 10)THEN
                PRINT*,' ITCNT > 10',' IT=',IT,' P=',P,' T1=',T1, &
                ' THES=',THES
                GO TO 40
            ENDIF
        
            DT = F1 * (T1 - T0) / (F1 - F0)
            T0 = T1
            F0 = F1
            T1 = T1 - DT
            GO TO 30
            40 CONTINUE
        
             TTAB(IT,KP) = T1
            QSTAB(IT,KP) = QS
        50 END DO
    60 END DO
!----------------------------------------------------------------------

!*** LOOKUP TABLE FOR TLOG(EMIX/ALIQ)

!*** SET UP INTIAL VALUES FOR LOOKUP TABLES

    ASTRT = 1.E-3
     AINC = 0.075

    A1 = ASTRT - AINC

    DO I=1,200
            A1 = A1 + AINC
        ALU(I) = ALOG(A1)
    ENDDO
!----------------------------------------------------------------------
    RETURN
    END SUBROUTINE LUTAB


